@@ -1041,6 +1041,7 @@ test_that(
 
     expect_equal(recommended_dose(x), 1)
     expect_true(is.integer(recommended_dose(x)))
+    expect_equal(length(recommended_dose(x)), 1)
 
     expect_equal(continue(x), FALSE)
     expect_true(is.logical(continue(x)))
@@ -1049,6 +1050,22 @@ test_that(
     expect_true(is.integer(n_at_dose(x)))
     expect_equal(length(n_at_dose(x)), num_doses(x))
 
+    expect_equal(n_at_dose(x, dose = 0), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 0)))
+    expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+    expect_equal(n_at_dose(x, dose = 1), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 1)))
+    expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+    expect_equal(n_at_dose(x, dose = 'recommended'), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+    expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+    expect_equal(n_at_recommended_dose(x), 3)
+    expect_true(is.integer(n_at_recommended_dose(x)))
+    expect_equal(length(n_at_recommended_dose(x)), 1)
+
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
@@ -1102,6 +1119,7 @@ test_that(
 
     expect_equal(recommended_dose(x), 1)
     expect_true(is.integer(recommended_dose(x)))
+    expect_equal(length(recommended_dose(x)), 1)
 
     expect_equal(continue(x), TRUE)
     expect_true(is.logical(continue(x)))
@@ -1110,6 +1128,22 @@ test_that(
     expect_true(is.integer(n_at_dose(x)))
     expect_equal(length(n_at_dose(x)), num_doses(x))
 
+    expect_equal(n_at_dose(x, dose = 0), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 0)))
+    expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+    expect_equal(n_at_dose(x, dose = 1), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 1)))
+    expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+    expect_equal(n_at_dose(x, dose = 'recommended'), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+    expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+    expect_equal(n_at_recommended_dose(x), 0)
+    expect_true(is.integer(n_at_recommended_dose(x)))
+    expect_equal(length(n_at_recommended_dose(x)), 1)
+
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -1169,6 +1203,7 @@ test_that(
 
     expect_equal(recommended_dose(x), 1)
     expect_true(is.integer(recommended_dose(x)))
+    expect_equal(length(recommended_dose(x)), 1)
 
     expect_equal(continue(x), FALSE)
     expect_true(is.logical(continue(x)))
@@ -1177,6 +1212,22 @@ test_that(
     expect_true(is.integer(n_at_dose(x)))
     expect_equal(length(n_at_dose(x)), num_doses(x))
 
+    expect_equal(n_at_dose(x, dose = 0), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 0)))
+    expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+    expect_equal(n_at_dose(x, dose = 1), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 1)))
+    expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+    expect_equal(n_at_dose(x, dose = 'recommended'), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+    expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+    expect_equal(n_at_recommended_dose(x), 3)
+    expect_true(is.integer(n_at_recommended_dose(x)))
+    expect_equal(length(n_at_recommended_dose(x)), 1)
+
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
@@ -1240,6 +1291,7 @@ test_that(
 
     expect_equal(recommended_dose(x), 1)
     expect_true(is.integer(recommended_dose(x)))
+    expect_equal(length(recommended_dose(x)), 1)
 
     expect_equal(continue(x), TRUE)
     expect_true(is.logical(continue(x)))
@@ -1248,6 +1300,22 @@ test_that(
     expect_true(is.integer(n_at_dose(x)))
     expect_equal(length(n_at_dose(x)), num_doses(x))
 
+    expect_equal(n_at_dose(x, dose = 0), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 0)))
+    expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+    expect_equal(n_at_dose(x, dose = 1), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 1)))
+    expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+    expect_equal(n_at_dose(x, dose = 'recommended'), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+    expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+    expect_equal(n_at_recommended_dose(x), 3)
+    expect_true(is.integer(n_at_recommended_dose(x)))
+    expect_equal(length(n_at_recommended_dose(x)), 1)
+
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
@@ -1301,6 +1369,7 @@ test_that(
 
     expect_equal(recommended_dose(x), 1)
     expect_true(is.integer(recommended_dose(x)))
+    expect_equal(length(recommended_dose(x)), 1)
 
     expect_equal(continue(x), TRUE)
     expect_true(is.logical(continue(x)))
@@ -1308,6 +1377,22 @@ test_that(
     expect_equal(n_at_dose(x), c(0,0,0,0,0))
     expect_true(is.integer(n_at_dose(x)))
 
+    expect_equal(n_at_dose(x, dose = 0), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 0)))
+    expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+    expect_equal(n_at_dose(x, dose = 1), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 1)))
+    expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+    expect_equal(n_at_dose(x, dose = 'recommended'), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+    expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+    expect_equal(n_at_recommended_dose(x), 0)
+    expect_true(is.integer(n_at_recommended_dose(x)))
+    expect_equal(length(n_at_recommended_dose(x)), 1)
+
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -1367,12 +1452,30 @@ test_that(
 
     expect_equal(recommended_dose(x), 1)
     expect_true(is.integer(recommended_dose(x)))
+    expect_equal(length(recommended_dose(x)), 1)
 
     expect_equal(continue(x), TRUE)
     expect_true(is.logical(continue(x)))
 
     expect_equal(n_at_dose(x), c(3,3,0,0,0))
     expect_true(is.integer(n_at_dose(x)))
+    expect_equal(length(n_at_dose(x)), 5)
+
+    expect_equal(n_at_dose(x, dose = 0), 0)
+    expect_true(is.integer(n_at_dose(x, dose = 0)))
+    expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+    expect_equal(n_at_dose(x, dose = 1), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 1)))
+    expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+    expect_equal(n_at_dose(x, dose = 'recommended'), 3)
+    expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+    expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+    expect_equal(n_at_recommended_dose(x), 3)
+    expect_true(is.integer(n_at_recommended_dose(x)))
+    expect_equal(length(n_at_recommended_dose(x)), 1)
 
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
